resvg_get_image_bbox

Function resvg_get_image_bbox 

#[unsafe(no_mangle)]
pub extern "C" fn resvg_get_image_bbox( tree: *const resvg_render_tree, bbox: *mut resvg_rect, ) -> bool
@brief Returns an image bounding box.

This bounding box contains the maximum SVG dimensions. It’s size can be bigger or smaller than #resvg_get_image_size Use it when you want to avoid clipping of elements that are outside the SVG viewbox.

@param tree Render tree. @param bbox Image’s bounding box. @return false if an image has no elements.