resvg_get_node_stroke_bbox

Function resvg_get_node_stroke_bbox 

#[unsafe(no_mangle)]
pub extern "C" fn resvg_get_node_stroke_bbox( tree: *const resvg_render_tree, id: *const c_char, bbox: *mut resvg_rect, ) -> bool
@brief Returns node’s bounding box, including stroke, in canvas coordinates by ID.

@param tree Render tree. @param id Node’s ID. Must not be NULL. @param bbox Node’s bounding box. @return false if a node with such an ID does not exist @return false if ID isn’t a UTF-8 string. @return false if ID is an empty string