resvg_node_exists

Function resvg_node_exists 

#[unsafe(no_mangle)]
pub extern "C" fn resvg_node_exists( tree: *const resvg_render_tree, id: *const c_char, ) -> bool
@brief Returns true if a renderable node with such an ID exists.

@param tree Render tree. @param id Node’s ID. UTF-8 string. Must not be NULL. @return true if a node exists. @return false if a node doesn’t exist or ID isn’t a UTF-8 string. @return false if a node exists, but not renderable.