resvg_options_load_font_data

Function resvg_options_load_font_data 

#[unsafe(no_mangle)]
pub extern "C" fn resvg_options_load_font_data( opt: *mut resvg_options, data: *const c_char, len: usize, )
@brief Loads a font data into the internal fonts database.

Prints a warning into the log when the data is not a valid TrueType font.

Has no effect when the text feature is not enabled.