resvg_render_node

Function resvg_render_node 

#[unsafe(no_mangle)]
pub extern "C" fn resvg_render_node( tree: *const resvg_render_tree, id: *const c_char, transform: resvg_transform, width: u32, height: u32, pixmap: *mut c_char, ) -> bool
@brief Renders a Node by ID onto the image.

@param tree A render tree. @param id Node’s ID. Must not be NULL. @param transform A root SVG transform. Can be used to position SVG inside the pixmap. @param width Pixmap width. @param height Pixmap height. @param pixmap Pixmap data. Should have widthheight4 size and contain premultiplied RGBA8888 pixels. @return false when id is not a non-empty UTF-8 string. @return false when the selected id is not present. @return false when an element has a zero bbox.